Index: include/asterisk/pbx.h
===================================================================
RCS file: /usr/cvsroot/asterisk/include/asterisk/pbx.h,v
retrieving revision 1.12
diff -u -u -r1.12 pbx.h
--- include/asterisk/pbx.h	1 Oct 2003 21:01:31 -0000	1.12
+++ include/asterisk/pbx.h	25 Oct 2003 02:53:38 -0000
@@ -376,6 +376,13 @@
  */
 int ast_context_remove_include2(struct ast_context *con, char *include, char *registrar);
 
+//! Verifies includes in an ast_contect structure
+/*!
+ * \param con context in which to verify the includes
+ * Returns 0 if no problems found, -1 if there were any missing context
+ */
+int ast_context_verify_includes(struct ast_context *con);
+	  
 //! Add a switch
 /*!
  * \param context context to which to add the switch
Index: pbx.c
===================================================================
RCS file: /usr/cvsroot/asterisk/pbx.c,v
retrieving revision 1.60
diff -u -u -r1.60 pbx.c
--- pbx.c	23 Oct 2003 03:55:58 -0000	1.60
+++ pbx.c	25 Oct 2003 02:53:41 -0000
@@ -4644,3 +4644,17 @@
 	else
 		return ip->next;
 }
+
+int ast_context_verify_includes(struct ast_context *con)
+{
+	struct ast_include *inc;
+	int res = 0;
+
+	for (inc = ast_walk_context_includes(con, NULL); inc; inc = ast_walk_context_includes(con, inc))
+		if (!ast_context_find(inc->rname)) {
+			res = -1;
+			ast_log(LOG_WARNING, "Context '%s' tries includes non-existant context '%s'\n",
+					ast_get_context_name(con), inc->rname);
+		}
+	return res;
+}
Index: pbx/pbx_config.c
===================================================================
RCS file: /usr/cvsroot/asterisk/pbx/pbx_config.c,v
retrieving revision 1.15
diff -u -u -r1.15 pbx_config.c
--- pbx/pbx_config.c	10 Sep 2003 05:24:49 -0000	1.15
+++ pbx/pbx_config.c	25 Oct 2003 02:53:42 -0000
@@ -1653,6 +1653,10 @@
 		ast_destroy(cfg);
 	}
 	ast_merge_contexts_and_delete(&local_contexts,registrar);
+
+	for (con = ast_walk_contexts(NULL); con; con = ast_walk_contexts(con))
+		ast_context_verify_includes(con);
+
 	return 0;
 }
 
